@@ -97,6 +97,23 @@ class LibvirtInspector(virt_inspector.Inspector):
 
             params = dict((p.get('name').lower(), p.get('value'))
                           for p in iface.findall('filterref/parameter'))
+
+            # Extract interface ID
+            try:
+                interfaceid = iface.find('virtualport').find(
+                    'parameters').get('interfaceid')
+            except AttributeError:
+                interfaceid = None
+
+            # Extract source bridge
+            try:
+                bridge = iface.find('source').get('bridge')
+            except AttributeError:
+                bridge = None
+
+            params['interfaceid'] = interfaceid
+            params['bridge'] = bridge
+
             dom_stats = domain.interfaceStats(name)
             yield virt_inspector.InterfaceStats(name=name,
                                                 mac=mac_address,
@@ -151,7 +168,10 @@ class LibvirtInspector(virt_inspector.Inspector):
         memory_swap_in = memory_swap_out = None
         memory_stats = domain.memoryStats()
         # Stat provided from libvirt is in KB, converting it to MB.
-        if 'available' in memory_stats and 'unused' in memory_stats:
+        if 'usable' in memory_stats and 'available' in memory_stats:
+            memory_used = (memory_stats['available'] -
+                           memory_stats['usable']) / units.Ki
+        elif 'available' in memory_stats and 'unused' in memory_stats:
             memory_used = (memory_stats['available'] -
                            memory_stats['unused']) / units.Ki
         if 'rss' in memory_stats:
