@@ -199,6 +199,7 @@ class GnocchiPublisher(publisher.ConfigPublisherBase):
         options = urlparse.parse_qs(parsed_url.query)
 
         self.filter_project = options.get('filter_project', ['service'])[-1]
+        self.filter_domain = options.get('filter_domain', ['Default'])[-1]
 
         resources_definition_file = options.get(
             'resources_definition_file', ['gnocchi_resources.yaml'])[-1]
@@ -252,7 +253,8 @@ class GnocchiPublisher(publisher.ConfigPublisherBase):
             pkg_resources.resource_filename(__name__,
                                             "data/gnocchi_resources.yaml"))
 
-        archive_policy_default = data.get("archive_policy_default", "low")
+        archive_policy_default = data.get("archive_policy_default",
+                                          "ceilometer-low")
         resource_defs = []
         for resource in data.get('resources', []):
             try:
@@ -261,18 +263,19 @@ class GnocchiPublisher(publisher.ConfigPublisherBase):
                     archive_policy_default,
                     archive_policy_override,
                     plugin_manager))
-            except Exception as exc:
-                LOG.error("Failed to load resource due to error %s" %
-                          exc)
+            except Exception:
+                LOG.error("Failed to load resource due to error",
+                          exc_info=True)
         return resource_defs, data.get("archive_policies", [])
 
     def ensures_archives_policies(self):
         if not self._already_configured_archive_policies:
             for ap in self.archive_policies_definition:
                 try:
-                    self._gnocchi.archive_policy.get(ap["name"])
-                except gnocchi_exc.ArchivePolicyNotFound:
                     self._gnocchi.archive_policy.create(ap)
+                except gnocchi_exc.ArchivePolicyAlreadyExists:
+                    # created in the meantime by another worker
+                    pass
             self._already_configured_archive_policies = True
 
     @property
@@ -283,7 +286,8 @@ class GnocchiPublisher(publisher.ConfigPublisherBase):
             if self._gnocchi_project_id is None:
                 try:
                     project = self._ks_client.projects.find(
-                        name=self.filter_project)
+                        name=self.filter_project,
+                        domain=self.filter_domain)
                 except ka_exceptions.NotFound:
                     LOG.warning('filtered project not found in keystone,'
                                 ' ignoring the filter_project '
