@@ -16,12 +16,11 @@
 """Tests for the compute pollsters.
 """
 
-import mock
 from oslotest import base
 import six
 
-from ceilometer.agent import manager
 from ceilometer.compute.pollsters import util
+from ceilometer.polling import manager
 from ceilometer import service
 
 
@@ -43,7 +42,6 @@ class FauxInstance(object):
 
 class TestLocationMetadata(base.BaseTestCase):
 
-    @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
     def setUp(self):
         self.CONF = service.prepare_service([], [])
         self.manager = manager.AgentManager(0, self.CONF)
