@@ -175,6 +175,9 @@ class PublisherTest(base.BaseTestCase):
         self.useFixture(fixtures.MockPatch(
             'ceilometer.keystone_client.get_client',
             return_value=ks_client))
+        self.useFixture(fixtures.MockPatch(
+            'gnocchiclient.v1.client.Client',
+            return_value=mock.Mock()))
         self.ks_client = ks_client
 
     def test_config_load(self):
@@ -198,7 +201,7 @@ class PublisherTest(base.BaseTestCase):
         plugin_manager = extension.ExtensionManager(
             namespace='ceilometer.event.trait.trait_plugin')
         rd = gnocchi.ResourcesDefinition(
-            resource, "low", plugin_manager)
+            resource, "high", "low", plugin_manager)
         operation = rd.event_match("image.delete")
         self.assertEqual('delete', operation)
 
@@ -245,12 +248,14 @@ class PublisherTest(base.BaseTestCase):
     def _do_test_activity_filter(self, expected_measures, fake_batch):
         url = netutils.urlsplit("gnocchi://")
         d = gnocchi.GnocchiPublisher(self.conf.conf, url)
+        d._already_checked_archive_policies = True
         d.publish_samples(self.samples)
         self.assertEqual(1, len(fake_batch.mock_calls))
         measures = fake_batch.mock_calls[0][1][0]
         self.assertEqual(
             expected_measures,
-            sum(len(m) for rid in measures for m in measures[rid].values()))
+            sum(len(m["measures"]) for rid in measures
+                for m in measures[rid].values()))
 
     def test_activity_filter_match_project_id(self):
         self.samples[0].project_id = (
@@ -266,7 +271,7 @@ class PublisherTest(base.BaseTestCase):
                                           'filter_project option')
 
     def test_activity_filter_match_swift_event(self):
-        self.samples[0].name = 'storage.api.request'
+        self.samples[0].name = 'storage.objects.outgoing.bytes'
         self.samples[0].resource_id = 'a2d42c23-d518-46b6-96ab-3fba2e146859'
         self._do_test_activity_filter(1)
 
@@ -290,6 +295,7 @@ class PublisherTest(base.BaseTestCase):
         )]
         url = netutils.urlsplit("gnocchi://")
         d = gnocchi.GnocchiPublisher(self.conf.conf, url)
+        d._already_checked_archive_policies = True
         d.publish_samples(samples)
         self.assertEqual(0, len(fake_batch.call_args[0][1]))
 
@@ -310,6 +316,43 @@ class PublisherWorkflowTest(base.BaseTestCase,
                             testscenarios.TestWithScenarios):
 
     sample_scenarios = [
+        ('cpu', dict(
+            sample=sample.Sample(
+                resource_id=str(uuid.uuid4()) + "_foobar",
+                name='cpu',
+                unit='ns',
+                type=sample.TYPE_CUMULATIVE,
+                volume=500,
+                user_id='test_user',
+                project_id='test_project',
+                source='openstack',
+                timestamp='2012-05-08 20:23:48.028195',
+                resource_metadata={
+                    'host': 'foo',
+                    'image_ref': 'imageref!',
+                    'instance_flavor_id': 1234,
+                    'display_name': 'myinstance',
+                },
+            ),
+            metric_attributes={
+                "archive_policy_name": "ceilometer-low-rate",
+                "unit": "ns",
+                "measures": [{
+                    'timestamp': '2012-05-08 20:23:48.028195',
+                    'value': 500
+                }]
+            },
+            postable_attributes={
+                'user_id': 'test_user',
+                'project_id': 'test_project',
+            },
+            patchable_attributes={
+                'host': 'foo',
+                'image_ref': 'imageref!',
+                'flavor_id': 1234,
+                'display_name': 'myinstance',
+            },
+            resource_type='instance')),
         ('disk.root.size', dict(
             sample=sample.Sample(
                 resource_id=str(uuid.uuid4()) + "_foobar",
@@ -328,10 +371,14 @@ class PublisherWorkflowTest(base.BaseTestCase,
                     'display_name': 'myinstance',
                 },
             ),
-            measures_attributes=[{
-                'timestamp': '2012-05-08 20:23:48.028195',
-                'value': 2
-            }],
+            metric_attributes={
+                "archive_policy_name": "ceilometer-low",
+                "unit": "GB",
+                "measures": [{
+                    'timestamp': '2012-05-08 20:23:48.028195',
+                    'value': 2
+                }]
+            },
             postable_attributes={
                 'user_id': 'test_user',
                 'project_id': 'test_project',
@@ -342,20 +389,6 @@ class PublisherWorkflowTest(base.BaseTestCase,
                 'flavor_id': 1234,
                 'display_name': 'myinstance',
             },
-            metric_names=[
-                'disk.root.size', 'disk.ephemeral.size',
-                'memory', 'vcpus', 'memory.usage', 'memory.resident',
-                'memory.swap.in', 'memory.swap.out',
-                'memory.bandwidth.total', 'memory.bandwidth.local',
-                'cpu', 'cpu.delta', 'cpu_util', 'vcpus', 'disk.read.requests',
-                'cpu_l3_cache', 'perf.cpu.cycles', 'perf.instructions',
-                'perf.cache.references', 'perf.cache.misses',
-                'disk.read.requests.rate', 'disk.write.requests',
-                'disk.write.requests.rate', 'disk.read.bytes',
-                'disk.read.bytes.rate', 'disk.write.bytes',
-                'disk.write.bytes.rate', 'disk.latency', 'disk.iops',
-                'disk.capacity', 'disk.allocation', 'disk.usage',
-                'compute.instance.booting.time'],
             resource_type='instance')),
         ('hardware.ipmi.node.power', dict(
             sample=sample.Sample(
@@ -372,25 +405,20 @@ class PublisherWorkflowTest(base.BaseTestCase,
                     'useless': 'not_used',
                 },
             ),
-            measures_attributes=[{
-                'timestamp': '2012-05-08 20:23:48.028195',
-                'value': 2
-            }],
+            metric_attributes={
+                "archive_policy_name": "ceilometer-low",
+                "unit": "W",
+                "measures": [{
+                    'timestamp': '2012-05-08 20:23:48.028195',
+                    'value': 2
+                }]
+            },
             postable_attributes={
                 'user_id': 'test_user',
                 'project_id': 'test_project',
             },
             patchable_attributes={
             },
-            metric_names=[
-                'hardware.ipmi.node.power', 'hardware.ipmi.node.temperature',
-                'hardware.ipmi.node.inlet_temperature',
-                'hardware.ipmi.node.outlet_temperature',
-                'hardware.ipmi.node.fan', 'hardware.ipmi.node.current',
-                'hardware.ipmi.node.voltage', 'hardware.ipmi.node.airflow',
-                'hardware.ipmi.node.cups', 'hardware.ipmi.node.cpu_util',
-                'hardware.ipmi.node.mem_util', 'hardware.ipmi.node.io_util'
-            ],
             resource_type='ipmi')),
     ]
 
@@ -460,9 +488,9 @@ class PublisherWorkflowTest(base.BaseTestCase,
         self.useFixture(utils_fixture.TimeFixture(now))
 
         expected_calls = [
-            mock.call.resource.search('instance_disk', search_params),
             mock.call.resource.search('instance_network_interface',
                                       search_params),
+            mock.call.resource.search('instance_disk', search_params),
             mock.call.resource.update(
                 'instance', '9f9d01b9-4a58-4271-9e27-398b21ab20d1',
                 {'ended_at': now.isoformat()}),
@@ -496,8 +524,6 @@ class PublisherWorkflowTest(base.BaseTestCase,
     @mock.patch('ceilometer.publisher.gnocchi.LOG')
     @mock.patch('gnocchiclient.v1.client.Client')
     def test_workflow(self, fakeclient_cls, logger):
-        url = netutils.urlsplit("gnocchi://")
-        self.publisher = gnocchi.GnocchiPublisher(self.conf.conf, url)
 
         fakeclient = fakeclient_cls.return_value
 
@@ -506,8 +532,26 @@ class PublisherWorkflowTest(base.BaseTestCase,
         gnocchi_id = uuid.uuid4()
 
         expected_calls = [
+            mock.call.archive_policy.create({"name": "ceilometer-low",
+                                             "back_window": 0,
+                                             "aggregation_methods": ["mean"],
+                                             "definition": mock.ANY}),
+            mock.call.archive_policy.create({"name": "ceilometer-low-rate",
+                                             "back_window": 0,
+                                             "aggregation_methods": [
+                                                 "mean", "rate:mean"],
+                                             "definition": mock.ANY}),
+            mock.call.archive_policy.create({"name": "ceilometer-high",
+                                             "back_window": 0,
+                                             "aggregation_methods": ["mean"],
+                                             "definition": mock.ANY}),
+            mock.call.archive_policy.create({"name": "ceilometer-high-rate",
+                                             "back_window": 0,
+                                             "aggregation_methods": [
+                                                 "mean", "rate:mean"],
+                                             "definition": mock.ANY}),
             mock.call.metric.batch_resources_metrics_measures(
-                {resource_id: {metric_name: self.measures_attributes}},
+                {resource_id: {metric_name: self.metric_attributes}},
                 create_metrics=True)
         ]
         expected_debug = [
@@ -530,15 +574,6 @@ class PublisherWorkflowTest(base.BaseTestCase,
             attributes = self.postable_attributes.copy()
             attributes.update(self.patchable_attributes)
             attributes['id'] = self.sample.resource_id
-            attributes['metrics'] = dict((metric_name, {})
-                                         for metric_name in self.metric_names)
-            for k, v in six.iteritems(attributes['metrics']):
-                if k == 'disk.root.size':
-                    v['unit'] = 'GB'
-                    continue
-                if k == 'hardware.ipmi.node.power':
-                    v['unit'] = 'W'
-                    continue
             expected_calls.append(mock.call.resource.create(
                 self.resource_type, attributes))
 
@@ -554,7 +589,7 @@ class PublisherWorkflowTest(base.BaseTestCase,
             if not self.create_resource_fail:
                 expected_calls.append(
                     mock.call.metric.batch_resources_metrics_measures(
-                        {resource_id: {metric_name: self.measures_attributes}},
+                        {resource_id: {metric_name: self.metric_attributes}},
                         create_metrics=True)
                 )
 
@@ -570,7 +605,8 @@ class PublisherWorkflowTest(base.BaseTestCase,
             batch_side_effect += [None]
             expected_debug.append(
                 mock.call("%d measures posted against %d metrics through %d "
-                          "resources", len(self.measures_attributes), 1, 1)
+                          "resources", len(self.metric_attributes["measures"]),
+                          1, 1)
             )
 
         if self.patchable_attributes:
@@ -586,7 +622,9 @@ class PublisherWorkflowTest(base.BaseTestCase,
         batch = fakeclient.metric.batch_resources_metrics_measures
         batch.side_effect = batch_side_effect
 
-        self.publisher.publish_samples([self.sample])
+        url = netutils.urlsplit("gnocchi://")
+        publisher = gnocchi.GnocchiPublisher(self.conf.conf, url)
+        publisher.publish_samples([self.sample])
 
         # Check that the last log message is the expected one
         if (self.post_measure_fail
@@ -599,4 +637,5 @@ class PublisherWorkflowTest(base.BaseTestCase,
         self.assertEqual(expected_calls, fakeclient.mock_calls)
         self.assertEqual(expected_debug, logger.debug.mock_calls)
 
+
 PublisherWorkflowTest.generate_scenarios()
