@@ -4,7 +4,7 @@
 # looks like
 #
 # [[local|localrc]]
-# enable_plugin ceilometer git://git.openstack.org/openstack/ceilometer
+# enable_plugin ceilometer https://git.openstack.org/openstack/ceilometer
 #
 # By default all ceilometer services are started (see devstack/settings)
 # except for the ceilometer-aipmi service. To disable a specific service
@@ -405,9 +405,9 @@ if is_service_enabled ceilometer; then
         start_ceilometer
     elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
         iniset $TEMPEST_CONFIG telemetry alarm_granularity $CEILOMETER_ALARM_GRANULARITY
-        iniset $TEMPEST_CONFIG telemetry alarm_threshold 10000000000
-        iniset $TEMPEST_CONFIG telemetry alarm_metric_name cpu
-        iniset $TEMPEST_CONFIG telemetry alarm_aggregation_method rate:mean
+        iniset $TEMPEST_CONFIG telemetry alarm_threshold $CEILOMETER_ALARM_THRESHOLD
+        iniset $TEMPEST_CONFIG telemetry alarm_metric_name $CEILOMETER_ALARM_METRIC_NAME
+        iniset $TEMPEST_CONFIG telemetry alarm_aggregation_method $CEILOMETER_ALARM_AGGREGATION_METHOD
     fi
 
     if [[ "$1" == "unstack" ]]; then
